@@ -1,6 +1,6 @@
 """Methods for referenceing Point objects: by.time, by.index, by.point"""
 
-class time(object):
+class Time(object):
     """When passed to \'by\', functions to state the Point object should be referenced by time. Essentially returns a string."""
     __slots__ = ['__by_method']
     def __init__(self):
@@ -10,7 +10,7 @@ class time(object):
     def by_method(self):
         return self.__by_method
 
-class index(object):
+class Index(object):
     """When passed to \'by\', functions to state the Point object should be referenced by point index. Essentially returns a string."""
     __slots__ = ['__by_method']
     def __init__(self):
@@ -20,7 +20,7 @@ class index(object):
     def by_method(self):
         return self.__by_method
 
-class point(object):
+class Point(object):
     """When passed to \'by\', functions to state the Point object should be referenced by the Point per se. Essentially returns a string."""
     __slots__ = ['__by_method']
     def __init__(self):
@@ -30,9 +30,9 @@ class point(object):
     def by_method(self):
         return self.__by_method
 
-time = time()
-index = index()
-point = point()
+time = Time()
+index = Index()
+point = Point()
 
 by_methods = [time.by_method,
               index.by_method,
