@@ -1,4 +1,4 @@
-from by import time as by_time, index as by_index, point as by_point
+import by as _by
 
 class PitchTier(object):
     """A PitchTier."""
@@ -113,7 +113,7 @@ class PitchTier(object):
         if point==None:
             pass
         else:
-            self.remove_point(point, by_point)
+            self.remove_point(point, _by.point)
             
             self._indexed = False
             point.time = target_time
@@ -141,7 +141,7 @@ class PitchTier(object):
 
         elif by.by_method=='by_index':
             for index in range(by_target[0], by_target[1]):
-                points.append(self.get_point(index, by_index))
+                points.append(self.get_point(index, _by.index))
                 
         elif by.by_method=='by_time':
             for point in self.__objects:
